Enum cargo_hatch::cli::Command

source ·
pub enum Command {
    Init {
        name: Option<String>,
    },
    List,
    New {
        bookmark: String,
        flags: CreationFlags,
    },
    Git {
        folder: Option<Utf8PathBuf>,
        url: String,
        flags: CreationFlags,
    },
    Local {
        path: Utf8PathBuf,
        flags: CreationFlags,
    },
    Completions {
        shell: Shell,
    },
    Manpages {
        dir: Utf8PathBuf,
    },
}

Variants



Init

Fields

name: Option<String>

Name of the new template, using the current working directory if omitted.

Initialize a new template with a sample configuration.



List

List all configured bookmarks with name and description.



New

Fields

bookmark: String

Bookmark as defined in the global configuration.

Create a new project from configured bookmarks.



Git

Fields

folder: Option<Utf8PathBuf>

An optional sub-folder within the repository that contains the template.

url: String

HTTP or Git URL to the remote repository.

Create a new project from a template located in a remote Git repository.



Local

Fields

path: Utf8PathBuf

Location of the template directory.

Create a new project from a template located in the local file system.



Completions

Fields

shell: Shell

Shell to generate an auto-completion script for.

Generate auto-completion scripts for various shells.



Manpages

Fields

dir: Utf8PathBuf

Target directory, that must already exist and be empty. If the any file with the same name as any of the man pages already exist, it’ll not be overwritten, but instead an error be returned.

Generate man pages into the given directory.