pub struct CreationFlags {
    pub name: Option<Utf8PathBuf>,
    pub update_deps: bool,
}

Fields

name: Option<Utf8PathBuf>

Name of the new project, using the current working directory if omitted.

If the name contains slashes /, it is treated as a file path and the target directory is created automatically if missing. The final project name will become the last part of the path.

update_deps: bool

Update all dependencies to the latest compatible version after project creation.