Enum cargo_hatch::cli::Command
source · pub enum Command {
Init {
name: Option<String>,
},
List,
New {
bookmark: String,
flags: CreationFlags,
},
Git {
folder: Option<Utf8PathBuf>,
url: String,
flags: CreationFlags,
},
Local {
path: Utf8PathBuf,
flags: CreationFlags,
},
Completions {
shell: Shell,
},
Manpages {
dir: Utf8PathBuf,
},
}Variants
Init
Fields
Initialize a new template with a sample configuration.
List
List all configured bookmarks with name and description.
New
Create a new project from configured bookmarks.
Git
Fields

folder: Option<Utf8PathBuf>An optional sub-folder within the repository that contains the template.

flags: CreationFlagsCreate a new project from a template located in a remote Git repository.
Local
Create a new project from a template located in the local file system.
Completions
Generate auto-completion scripts for various shells.
Manpages
Fields

dir: Utf8PathBufTarget directory, that must already exist and be empty. If the any file with the same name as any of the man pages already exist, it’ll not be overwritten, but instead an error be returned.
Generate man pages into the given directory.